package MyA;
use 5.010;
use strict;
use warnings;

use MyB;

sub run { say 'MyA' }

1;

